pub struct GeneratedDbApi<'a> { /* private fields */ }Expand description
Auto-generated API methods.
Implementations
Sourceimpl<'a> GeneratedDbApi<'a>
impl<'a> GeneratedDbApi<'a>
pub fn new(http: &'a HttpClient) -> Self
Sourcepub async fn get_health(&self) -> Result<Value, Error>
pub async fn get_health(&self) -> Result<Value, Error>
Health check — GET /api/health
Sourcepub async fn auth_signup(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_signup(&self, body: &Value) -> Result<Value, Error>
Sign up with email and password — POST /api/auth/signup
Sourcepub async fn auth_signin(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_signin(&self, body: &Value) -> Result<Value, Error>
Sign in with email and password — POST /api/auth/signin
Sourcepub async fn auth_signin_anonymous(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_signin_anonymous(&self, body: &Value) -> Result<Value, Error>
Sign in anonymously — POST /api/auth/signin/anonymous
Sourcepub async fn auth_signin_magic_link(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_signin_magic_link(&self, body: &Value) -> Result<Value, Error>
Send magic link to email — POST /api/auth/signin/magic-link
Sourcepub async fn auth_verify_magic_link(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_verify_magic_link(&self, body: &Value) -> Result<Value, Error>
Verify magic link token — POST /api/auth/verify-magic-link
Sourcepub async fn auth_signin_phone(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_signin_phone(&self, body: &Value) -> Result<Value, Error>
Send OTP SMS to phone number — POST /api/auth/signin/phone
Sourcepub async fn auth_verify_phone(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_verify_phone(&self, body: &Value) -> Result<Value, Error>
Verify phone OTP and create session — POST /api/auth/verify-phone
Sourcepub async fn auth_link_phone(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_link_phone(&self, body: &Value) -> Result<Value, Error>
Link phone number to existing account — POST /api/auth/link/phone
Sourcepub async fn auth_verify_link_phone(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_verify_link_phone(&self, body: &Value) -> Result<Value, Error>
Verify OTP and link phone to account — POST /api/auth/verify-link-phone
Sourcepub async fn auth_signin_email_otp(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_signin_email_otp(&self, body: &Value) -> Result<Value, Error>
Send OTP code to email — POST /api/auth/signin/email-otp
Sourcepub async fn auth_verify_email_otp(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_verify_email_otp(&self, body: &Value) -> Result<Value, Error>
Verify email OTP and create session — POST /api/auth/verify-email-otp
Sourcepub async fn auth_mfa_totp_enroll(&self) -> Result<Value, Error>
pub async fn auth_mfa_totp_enroll(&self) -> Result<Value, Error>
Enroll new TOTP factor — POST /api/auth/mfa/totp/enroll
Sourcepub async fn auth_mfa_totp_verify(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_mfa_totp_verify(&self, body: &Value) -> Result<Value, Error>
Confirm TOTP enrollment with code — POST /api/auth/mfa/totp/verify
Sourcepub async fn auth_mfa_verify(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_mfa_verify(&self, body: &Value) -> Result<Value, Error>
Verify MFA code during signin — POST /api/auth/mfa/verify
Sourcepub async fn auth_mfa_recovery(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_mfa_recovery(&self, body: &Value) -> Result<Value, Error>
Use recovery code during MFA signin — POST /api/auth/mfa/recovery
Sourcepub async fn auth_mfa_totp_delete(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_mfa_totp_delete(&self, body: &Value) -> Result<Value, Error>
Disable TOTP factor — DELETE /api/auth/mfa/totp
Sourcepub async fn auth_mfa_factors(&self) -> Result<Value, Error>
pub async fn auth_mfa_factors(&self) -> Result<Value, Error>
List MFA factors for authenticated user — GET /api/auth/mfa/factors
Sourcepub async fn auth_refresh(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_refresh(&self, body: &Value) -> Result<Value, Error>
Refresh access token — POST /api/auth/refresh
Sourcepub async fn auth_signout(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_signout(&self, body: &Value) -> Result<Value, Error>
Sign out and revoke refresh token — POST /api/auth/signout
Sourcepub async fn auth_change_password(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_change_password(&self, body: &Value) -> Result<Value, Error>
Change password for authenticated user — POST /api/auth/change-password
Sourcepub async fn auth_change_email(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_change_email(&self, body: &Value) -> Result<Value, Error>
Request email change with password confirmation — POST /api/auth/change-email
Sourcepub async fn auth_verify_email_change(
&self,
body: &Value,
) -> Result<Value, Error>
pub async fn auth_verify_email_change( &self, body: &Value, ) -> Result<Value, Error>
Verify email change token — POST /api/auth/verify-email-change
Sourcepub async fn auth_passkeys_register_options(&self) -> Result<Value, Error>
pub async fn auth_passkeys_register_options(&self) -> Result<Value, Error>
Generate passkey registration options — POST /api/auth/passkeys/register-options
Sourcepub async fn auth_passkeys_register(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_passkeys_register(&self, body: &Value) -> Result<Value, Error>
Verify and store passkey registration — POST /api/auth/passkeys/register
Sourcepub async fn auth_passkeys_auth_options(
&self,
body: &Value,
) -> Result<Value, Error>
pub async fn auth_passkeys_auth_options( &self, body: &Value, ) -> Result<Value, Error>
Generate passkey authentication options — POST /api/auth/passkeys/auth-options
Sourcepub async fn auth_passkeys_authenticate(
&self,
body: &Value,
) -> Result<Value, Error>
pub async fn auth_passkeys_authenticate( &self, body: &Value, ) -> Result<Value, Error>
Authenticate with passkey — POST /api/auth/passkeys/authenticate
Sourcepub async fn auth_passkeys_list(&self) -> Result<Value, Error>
pub async fn auth_passkeys_list(&self) -> Result<Value, Error>
List passkeys for authenticated user — GET /api/auth/passkeys
Sourcepub async fn auth_passkeys_delete(
&self,
credential_id: &str,
) -> Result<Value, Error>
pub async fn auth_passkeys_delete( &self, credential_id: &str, ) -> Result<Value, Error>
Delete a passkey — DELETE /api/auth/passkeys/{credentialId}
Sourcepub async fn auth_get_me(&self) -> Result<Value, Error>
pub async fn auth_get_me(&self) -> Result<Value, Error>
Get current authenticated user info — GET /api/auth/me
Sourcepub async fn auth_update_profile(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_update_profile(&self, body: &Value) -> Result<Value, Error>
Update user profile — PATCH /api/auth/profile
Sourcepub async fn auth_get_sessions(&self) -> Result<Value, Error>
pub async fn auth_get_sessions(&self) -> Result<Value, Error>
List active sessions — GET /api/auth/sessions
Sourcepub async fn auth_delete_session(&self, id: &str) -> Result<Value, Error>
pub async fn auth_delete_session(&self, id: &str) -> Result<Value, Error>
Delete a session — DELETE /api/auth/sessions/{id}
Sourcepub async fn auth_get_identities(&self) -> Result<Value, Error>
pub async fn auth_get_identities(&self) -> Result<Value, Error>
List linked sign-in identities for the current user — GET /api/auth/identities
Sourcepub async fn auth_delete_identity(
&self,
identity_id: &str,
) -> Result<Value, Error>
pub async fn auth_delete_identity( &self, identity_id: &str, ) -> Result<Value, Error>
Unlink a linked sign-in identity — DELETE /api/auth/identities/{identityId}
Sourcepub async fn auth_link_email(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_link_email(&self, body: &Value) -> Result<Value, Error>
Link email and password to existing account — POST /api/auth/link/email
Sourcepub async fn auth_request_email_verification(
&self,
body: &Value,
) -> Result<Value, Error>
pub async fn auth_request_email_verification( &self, body: &Value, ) -> Result<Value, Error>
Send a verification email to the current authenticated user — POST /api/auth/request-email-verification
Sourcepub async fn auth_verify_email(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_verify_email(&self, body: &Value) -> Result<Value, Error>
Verify email address with token — POST /api/auth/verify-email
Sourcepub async fn auth_request_password_reset(
&self,
body: &Value,
) -> Result<Value, Error>
pub async fn auth_request_password_reset( &self, body: &Value, ) -> Result<Value, Error>
Request password reset email — POST /api/auth/request-password-reset
Sourcepub async fn auth_reset_password(&self, body: &Value) -> Result<Value, Error>
pub async fn auth_reset_password(&self, body: &Value) -> Result<Value, Error>
Reset password with token — POST /api/auth/reset-password
Sourcepub async fn oauth_redirect(&self, provider: &str) -> Result<Value, Error>
pub async fn oauth_redirect(&self, provider: &str) -> Result<Value, Error>
Start OAuth redirect — GET /api/auth/oauth/{provider}
Sourcepub async fn oauth_callback(&self, provider: &str) -> Result<Value, Error>
pub async fn oauth_callback(&self, provider: &str) -> Result<Value, Error>
OAuth callback — GET /api/auth/oauth/{provider}/callback
Sourcepub async fn oauth_link_start(&self, provider: &str) -> Result<Value, Error>
pub async fn oauth_link_start(&self, provider: &str) -> Result<Value, Error>
Start OAuth account linking — POST /api/auth/oauth/link/{provider}
Sourcepub async fn oauth_link_callback(&self, provider: &str) -> Result<Value, Error>
pub async fn oauth_link_callback(&self, provider: &str) -> Result<Value, Error>
OAuth link callback — GET /api/auth/oauth/link/{provider}/callback
Sourcepub async fn db_single_count_records(
&self,
namespace: &str,
table: &str,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_single_count_records( &self, namespace: &str, table: &str, query: &HashMap<String, String>, ) -> Result<Value, Error>
Count records in a single-instance table — GET /api/db/{namespace}/tables/{table}/count
Sourcepub async fn db_single_search_records(
&self,
namespace: &str,
table: &str,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_single_search_records( &self, namespace: &str, table: &str, query: &HashMap<String, String>, ) -> Result<Value, Error>
Search records in a single-instance table — GET /api/db/{namespace}/tables/{table}/search
Sourcepub async fn db_single_get_record(
&self,
namespace: &str,
table: &str,
id: &str,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_single_get_record( &self, namespace: &str, table: &str, id: &str, query: &HashMap<String, String>, ) -> Result<Value, Error>
Get a single record from a single-instance table — GET /api/db/{namespace}/tables/{table}/{id}
Sourcepub async fn db_single_update_record(
&self,
namespace: &str,
table: &str,
id: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn db_single_update_record( &self, namespace: &str, table: &str, id: &str, body: &Value, ) -> Result<Value, Error>
Update a record in a single-instance table — PATCH /api/db/{namespace}/tables/{table}/{id}
Sourcepub async fn db_single_delete_record(
&self,
namespace: &str,
table: &str,
id: &str,
) -> Result<Value, Error>
pub async fn db_single_delete_record( &self, namespace: &str, table: &str, id: &str, ) -> Result<Value, Error>
Delete a record from a single-instance table — DELETE /api/db/{namespace}/tables/{table}/{id}
Sourcepub async fn db_single_list_records(
&self,
namespace: &str,
table: &str,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_single_list_records( &self, namespace: &str, table: &str, query: &HashMap<String, String>, ) -> Result<Value, Error>
List records from a single-instance table — GET /api/db/{namespace}/tables/{table}
Sourcepub async fn db_single_insert_record(
&self,
namespace: &str,
table: &str,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_single_insert_record( &self, namespace: &str, table: &str, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Insert a record into a single-instance table — POST /api/db/{namespace}/tables/{table}
Sourcepub async fn db_single_batch_records(
&self,
namespace: &str,
table: &str,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_single_batch_records( &self, namespace: &str, table: &str, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Batch insert records into a single-instance table — POST /api/db/{namespace}/tables/{table}/batch
Sourcepub async fn db_single_batch_by_filter(
&self,
namespace: &str,
table: &str,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_single_batch_by_filter( &self, namespace: &str, table: &str, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Batch update/delete records by filter in a single-instance table — POST /api/db/{namespace}/tables/{table}/batch-by-filter
Sourcepub async fn db_count_records(
&self,
namespace: &str,
instance_id: &str,
table: &str,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_count_records( &self, namespace: &str, instance_id: &str, table: &str, query: &HashMap<String, String>, ) -> Result<Value, Error>
Count records in dynamic table — GET /api/db/{namespace}/{instanceId}/tables/{table}/count
Sourcepub async fn db_search_records(
&self,
namespace: &str,
instance_id: &str,
table: &str,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_search_records( &self, namespace: &str, instance_id: &str, table: &str, query: &HashMap<String, String>, ) -> Result<Value, Error>
Search records in dynamic table — GET /api/db/{namespace}/{instanceId}/tables/{table}/search
Sourcepub async fn db_get_record(
&self,
namespace: &str,
instance_id: &str,
table: &str,
id: &str,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_get_record( &self, namespace: &str, instance_id: &str, table: &str, id: &str, query: &HashMap<String, String>, ) -> Result<Value, Error>
Get single record from dynamic table — GET /api/db/{namespace}/{instanceId}/tables/{table}/{id}
Sourcepub async fn db_update_record(
&self,
namespace: &str,
instance_id: &str,
table: &str,
id: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn db_update_record( &self, namespace: &str, instance_id: &str, table: &str, id: &str, body: &Value, ) -> Result<Value, Error>
Update record in dynamic table — PATCH /api/db/{namespace}/{instanceId}/tables/{table}/{id}
Sourcepub async fn db_delete_record(
&self,
namespace: &str,
instance_id: &str,
table: &str,
id: &str,
) -> Result<Value, Error>
pub async fn db_delete_record( &self, namespace: &str, instance_id: &str, table: &str, id: &str, ) -> Result<Value, Error>
Delete record from dynamic table — DELETE /api/db/{namespace}/{instanceId}/tables/{table}/{id}
Sourcepub async fn db_list_records(
&self,
namespace: &str,
instance_id: &str,
table: &str,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_list_records( &self, namespace: &str, instance_id: &str, table: &str, query: &HashMap<String, String>, ) -> Result<Value, Error>
List records from dynamic table — GET /api/db/{namespace}/{instanceId}/tables/{table}
Sourcepub async fn db_insert_record(
&self,
namespace: &str,
instance_id: &str,
table: &str,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_insert_record( &self, namespace: &str, instance_id: &str, table: &str, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Insert record into dynamic table — POST /api/db/{namespace}/{instanceId}/tables/{table}
Sourcepub async fn db_batch_records(
&self,
namespace: &str,
instance_id: &str,
table: &str,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_batch_records( &self, namespace: &str, instance_id: &str, table: &str, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Batch insert records into dynamic table — POST /api/db/{namespace}/{instanceId}/tables/{table}/batch
Sourcepub async fn db_batch_by_filter(
&self,
namespace: &str,
instance_id: &str,
table: &str,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn db_batch_by_filter( &self, namespace: &str, instance_id: &str, table: &str, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Batch update/delete records by filter in dynamic table — POST /api/db/{namespace}/{instanceId}/tables/{table}/batch-by-filter
Sourcepub async fn check_database_subscription_connection(
&self,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn check_database_subscription_connection( &self, query: &HashMap<String, String>, ) -> Result<Value, Error>
Check database live subscription WebSocket prerequisites — GET /api/db/connect-check
Sourcepub async fn connect_database_subscription(
&self,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn connect_database_subscription( &self, query: &HashMap<String, String>, ) -> Result<Value, Error>
Connect to database live subscriptions WebSocket — GET /api/db/subscribe
Sourcepub async fn get_schema(&self) -> Result<Value, Error>
pub async fn get_schema(&self) -> Result<Value, Error>
Get table schema — GET /api/schema
Sourcepub async fn upload_file(
&self,
bucket: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn upload_file( &self, bucket: &str, body: &Value, ) -> Result<Value, Error>
Upload file — POST /api/storage/{bucket}/upload
Sourcepub async fn get_file_metadata(
&self,
bucket: &str,
key: &str,
) -> Result<Value, Error>
pub async fn get_file_metadata( &self, bucket: &str, key: &str, ) -> Result<Value, Error>
Get file metadata — GET /api/storage/{bucket}/{key}/metadata
Sourcepub async fn update_file_metadata(
&self,
bucket: &str,
key: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn update_file_metadata( &self, bucket: &str, key: &str, body: &Value, ) -> Result<Value, Error>
Update file metadata — PATCH /api/storage/{bucket}/{key}/metadata
Sourcepub async fn check_file_exists(
&self,
bucket: &str,
key: &str,
) -> Result<bool, Error>
pub async fn check_file_exists( &self, bucket: &str, key: &str, ) -> Result<bool, Error>
Check if file exists — HEAD /api/storage/{bucket}/{key}
Sourcepub async fn download_file(
&self,
bucket: &str,
key: &str,
) -> Result<Value, Error>
pub async fn download_file( &self, bucket: &str, key: &str, ) -> Result<Value, Error>
Download file — GET /api/storage/{bucket}/{key}
Sourcepub async fn delete_file(&self, bucket: &str, key: &str) -> Result<Value, Error>
pub async fn delete_file(&self, bucket: &str, key: &str) -> Result<Value, Error>
Delete file — DELETE /api/storage/{bucket}/{key}
Sourcepub async fn get_upload_parts(
&self,
bucket: &str,
upload_id: &str,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn get_upload_parts( &self, bucket: &str, upload_id: &str, query: &HashMap<String, String>, ) -> Result<Value, Error>
Get uploaded parts — GET /api/storage/{bucket}/uploads/{uploadId}/parts
Sourcepub async fn list_files(&self, bucket: &str) -> Result<Value, Error>
pub async fn list_files(&self, bucket: &str) -> Result<Value, Error>
List files in bucket — GET /api/storage/{bucket}
Sourcepub async fn delete_batch(
&self,
bucket: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn delete_batch( &self, bucket: &str, body: &Value, ) -> Result<Value, Error>
Batch delete files — POST /api/storage/{bucket}/delete-batch
Sourcepub async fn create_signed_download_url(
&self,
bucket: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn create_signed_download_url( &self, bucket: &str, body: &Value, ) -> Result<Value, Error>
Create signed download URL — POST /api/storage/{bucket}/signed-url
Sourcepub async fn create_signed_download_urls(
&self,
bucket: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn create_signed_download_urls( &self, bucket: &str, body: &Value, ) -> Result<Value, Error>
Batch create signed download URLs — POST /api/storage/{bucket}/signed-urls
Sourcepub async fn create_signed_upload_url(
&self,
bucket: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn create_signed_upload_url( &self, bucket: &str, body: &Value, ) -> Result<Value, Error>
Create signed upload URL — POST /api/storage/{bucket}/signed-upload-url
Sourcepub async fn create_multipart_upload(
&self,
bucket: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn create_multipart_upload( &self, bucket: &str, body: &Value, ) -> Result<Value, Error>
Start multipart upload — POST /api/storage/{bucket}/multipart/create
Sourcepub async fn upload_part(
&self,
bucket: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn upload_part( &self, bucket: &str, body: &Value, ) -> Result<Value, Error>
Upload a part — POST /api/storage/{bucket}/multipart/upload-part
Sourcepub async fn complete_multipart_upload(
&self,
bucket: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn complete_multipart_upload( &self, bucket: &str, body: &Value, ) -> Result<Value, Error>
Complete multipart upload — POST /api/storage/{bucket}/multipart/complete
Sourcepub async fn abort_multipart_upload(
&self,
bucket: &str,
body: &Value,
) -> Result<Value, Error>
pub async fn abort_multipart_upload( &self, bucket: &str, body: &Value, ) -> Result<Value, Error>
Abort multipart upload — POST /api/storage/{bucket}/multipart/abort
Sourcepub async fn get_config(&self) -> Result<Value, Error>
pub async fn get_config(&self) -> Result<Value, Error>
Get public configuration — GET /api/config
Sourcepub async fn push_register(&self, body: &Value) -> Result<Value, Error>
pub async fn push_register(&self, body: &Value) -> Result<Value, Error>
Register push token — POST /api/push/register
Sourcepub async fn push_unregister(&self, body: &Value) -> Result<Value, Error>
pub async fn push_unregister(&self, body: &Value) -> Result<Value, Error>
Unregister push token — POST /api/push/unregister
Sourcepub async fn push_topic_subscribe(&self, body: &Value) -> Result<Value, Error>
pub async fn push_topic_subscribe(&self, body: &Value) -> Result<Value, Error>
Subscribe token to topic — POST /api/push/topic/subscribe
Sourcepub async fn push_topic_unsubscribe(&self, body: &Value) -> Result<Value, Error>
pub async fn push_topic_unsubscribe(&self, body: &Value) -> Result<Value, Error>
Unsubscribe token from topic — POST /api/push/topic/unsubscribe
Sourcepub async fn check_room_connection(
&self,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn check_room_connection( &self, query: &HashMap<String, String>, ) -> Result<Value, Error>
Check room WebSocket connection prerequisites — GET /api/room/connect-check
Sourcepub async fn connect_room(
&self,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn connect_room( &self, query: &HashMap<String, String>, ) -> Result<Value, Error>
Connect to room WebSocket — GET /api/room
Sourcepub async fn get_room_metadata(
&self,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn get_room_metadata( &self, query: &HashMap<String, String>, ) -> Result<Value, Error>
Get room metadata — GET /api/room/metadata
Sourcepub async fn get_room_realtime_session(
&self,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn get_room_realtime_session( &self, query: &HashMap<String, String>, ) -> Result<Value, Error>
Get the active room realtime media session — GET /api/room/media/realtime/session
Sourcepub async fn create_room_realtime_session(
&self,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn create_room_realtime_session( &self, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Create a room realtime media session — POST /api/room/media/realtime/session
Sourcepub async fn create_room_realtime_ice_servers(
&self,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn create_room_realtime_ice_servers( &self, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Generate TURN / ICE credentials for room realtime media — POST /api/room/media/realtime/turn
Sourcepub async fn add_room_realtime_tracks(
&self,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn add_room_realtime_tracks( &self, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Add realtime media tracks to a room session — POST /api/room/media/realtime/tracks/new
Sourcepub async fn renegotiate_room_realtime_session(
&self,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn renegotiate_room_realtime_session( &self, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Renegotiate a room realtime media session — PUT /api/room/media/realtime/renegotiate
Sourcepub async fn close_room_realtime_tracks(
&self,
body: &Value,
query: &HashMap<String, String>,
) -> Result<Value, Error>
pub async fn close_room_realtime_tracks( &self, body: &Value, query: &HashMap<String, String>, ) -> Result<Value, Error>
Close room realtime media tracks — PUT /api/room/media/realtime/tracks/close